function findClasses($el, regexp) {
  var classes = $el[0].className.split(' ');
  var str = '';
  classes.forEach(function(cls){
    if (regexp.test(cls)) {
      str += cls + ' ';
    }
  });
  return(str);
};

function rmCls($el, regexp, str) {
  var classes = str + findClasses($el, regexp);
  $el.removeClass(classes);
}

function removeClasses($el, regexp, str) {
  var str = str || '';
  if (regexp.length) {
    regexp.forEach(function(rgxp) {
      rmCls($el, rgxp, str);
    });
  } else {
    rmCls($el, regexp, str);
  }
}

function clipClass($el, regexp) {
  return findClasses($el, regexp).replace(regexp, '');
}
'use strict';

$housePage = $('[data-js-house-page]');

if ($housePage.length) {
  var regexp_h = /^_house_/;
  var house = findClasses($housePage, regexp_h).replace(regexp_h, '');
  $('[data-js-house-num]').text(house);
}

$('[data-js-section-choose]').click(function () {
  var dir = $(this).attr('data-js-section-choose');
  var regexp_s = /^_section_/;
  var section = +findClasses($housePage, regexp_s).replace(regexp_s, '');
  var length = $housePage.find('[data-js-overlay-section]').length;
  if (dir == 'prev') {
    if (section != 1) {
      --section;
    } else {
      section = length;
    }
  } else {
    if (section < length) {
      ++section;
    } else {
      section = 1;
    }
  }
  removeClasses($housePage, regexp_s);
  $housePage.addClass('_section _section_' + section);
  $('[data-js-section-num]').text(section);
});
"use strict";
"use strict";
'use strict';

var $body = $('body');
var $housePage = $('[data-js-house-page]');
var $floorModal = $('[data-js-modal=floor]');
var $flatModal = $('[data-js-modal=flat]');
var $closeModal = $('[data-js-close-modal]');
var $switchFloor = $('[data-js-switch-floor]');
var $floorNum = $('[data-js-floor-num]');

var house = '';
var section = '';
var floors = '';
var floor = '';

var regexp_h = /^_house_/;
var regexp_s = /^_section_/;
var regexp_f = /^_floor_/;
var regexp_fs = /^_floors_/;
var regexp_flat = /^_flat_/;

var $rooms = $('[data-js-rooms-value]');
var $size = $('[data-js-size-value]');
var $price = $('[data-js-price-value]');
var $img = $('[data-js-flat-img]');

// need to add _state_sold class before defining $showModal var
$('[data-js-floor-flat=gp3-2euro-1]').addClass('_state_sold');
var $showModal = $('[data-js-show-modal]').not('._state_sold');

$showModal.click(function () {
  if ($housePage.length) {
    removeClasses($body, /^_modal/);
    var modal = $(this).attr('data-js-show-modal');
    section = clipClass($housePage, regexp_s);
    floors = $('[data-js-overlay-section=' + section + ']').find('.floor').length;

    house = clipClass($housePage, regexp_h);

    if (house == 3) {
      $body.addClass('_modal_shown _modal_' + modal);
      if (modal == 'floor') {
        removeClasses($floorModal, [regexp_fs, regexp_f]);
        floor = $(this).attr('data-js-floor');
        $floorModal.addClass('_house_' + house + ' _section_' + section + ' _floors_' + floors + ' _floor_' + floor);
        $floorNum.text(floor);
      } else {
        removeClasses($flatModal, [regexp_fs, regexp_f]);

        // ==== Add data to flat modal
        floorClass = findClasses($floorModal, regexp_f);
        floor = floorClass.replace(regexp_f, '');
        $flatModal.addClass('_floors_' + floors + ' ' + floorClass + ' _flat_' + flat);

        var flat = $(this).attr('data-js-floor-flat');
        var tooltip = $(this).find($tooltip);
        var rooms = tooltip.find($rooms).text();
        var size = tooltip.find($size).text();
        var price = tooltip.find($price).text();

        var img = "static/img/minified-svg/" + flat + ".svg";
        $flatModal.find($img).attr({ 'src': img });
        $flatModal.find($rooms).text(rooms);
        $flatModal.find($size).text(size);
        $flatModal.find($price).text(price);
      }
    }
  }
});

$switchFloor.click(function () {
  var dir = $(this).attr('data-js-switch-floor');
  var $thisModal = $(this).closest('[data-js-modal]');
  floor = +clipClass($thisModal, regexp_f);
  floors = +clipClass($thisModal, regexp_fs);
  if (dir == 'prev') {
    if (floor != 1) {
      --floor;
    } else {
      floor = floors;
    }
  } else {
    if (floor < floors) {
      ++floor;
    } else {
      floor = 1;
    }
  }
  removeClasses($floorModal, regexp_f);
  removeClasses($flatModal, regexp_f);
  $floorModal.addClass('_floor_' + floor);
  $flatModal.addClass('_floor_' + floor);
  $floorNum.text(floor);
});

$closeModal.click(function () {
  if ($body.hasClass('_modal_flat')) {
    removeClasses($flatModal, [regexp_fs, regexp_f, regexp_flat]);
    $body.removeClass('_modal_flat').addClass('_modal_floor');
  } else {
    removeClasses($floorModal, [regexp_h, regexp_s, regexp_fs, regexp_f]);
    removeClasses($body, /^_modal/);
  }
});
'use strict';

var $tooltip = $('[data-js-flat-tooltip]');
var $sold = $('[data-js-sold-tooltip]');
var $floorflat = $('[data-js-floor-flat]');
var $shape = $('[id^="shape"]');
var $select = $('[data-js-select-flats]');

$("[style*='fill:#ABE1FA']").closest($floorflat).addClass('_type_studio');
$("[style*='fill:#B0ACD5']").closest($floorflat).addClass('_type_1room');
$("[style*='fill:#BCD640']").closest($floorflat).addClass('_type_2rooms');
$("[style*='fill:#DEB9D8']").closest($floorflat).addClass('_type_3rooms');
$("[style*='fill:#FBB040']").closest($floorflat).addClass('_type_2euro');
$("[style*='fill:#FBF394']").closest($floorflat).addClass('_type_3euro');

$shape.hover(function () {
  $(this).closest($floorflat).addClass('_display_tooltip');
}, function () {
  $(this).closest($floorflat).removeClass('_display_tooltip');
});

$shape.mousemove(function (e) {
  var $thisFlat = $(this).closest($floorflat);
  var top = $thisFlat.offset().top;
  var left = $thisFlat.offset().left;
  var x = e.clientX - left;
  var y = e.clientY - top;
  $thisFlat.find($tooltip).css({ 'top': y, 'left': x });
  if ($thisFlat.hasClass('_state_sold')) {
    $thisFlat.find($sold).css({ 'top': y, 'left': x });
  }
});

$select.hover(function () {
  var selector = $(this).attr('data-js-select-flats');
  var selected = $('[data-js-floor-flat]._type_' + selector);
  selected.addClass('_hover');
}, function () {
  $floorflat.removeClass('_hover');
});
"use strict";
"use strict";
"use strict";
'use strict';

var $nav = $('[data-js-nav]');

$('[data-js-nav-icon]').on('click', function (e) {
  e.preventDefault();
  $(this).toggleClass('_nav-close');
  $nav.toggleClass('_opened');
  if ($nav.hasClass('_opened')) {
    setTimeout(function () {
      $nav.addClass('_overflow_visible');
    }, 500);
  } else {
    $nav.removeClass('_overflow_visible');
  }
});

if (/Android|webOS|iPhone|iPad|iPod|BlackBerry/i.test(navigator.userAgent)) {
  window.isMobile = true;
} else {
  window.isMobile = false;
}

if (window.isMobile) {
  $('.page').addClass('_orientation-cover_true');
}

// function checkOrientation () {
//   if (+window.orientation != 90 && +window.orientation != -90) {
//     console.log(window.orientation)
//     alert('Переверните девайс')
//   }
// }
//
// window.addEventListener("orientationchange", function() {
//   checkOrientation();
// }, false);
//
// checkOrientation();
'use strict';

var $housePage = $('[data-js-house-page]');

$('[data-js-overlay-section]').click(function (e) {
  var section = $(this).attr('data-js-overlay-section');
  if (!$housePage.hasClass('_section')) {
    $housePage.addClass('_section _section_' + section);
    $('[data-js-section-num]').text(section);
  }
});

$('[data-js-btn-back]').on('click', function (e) {
  e.preventDefault();
  if ($housePage.hasClass('_section')) {
    removeClasses($housePage, /^_section/);
  }
});